@@ -1,3 +1,4 @@
+require(dplyr)
 rxPermissive({
 
     for (radi in c(1, 2, 3)){
@@ -463,19 +464,19 @@ rxPermissive({
             expect_false(inherits(tmp$evid, "rxEvid"))
         })
 
-        test_that("tibble conversion", {
-            tmp <- tibble::as_tibble(ev)
-            expect_equal(names(tmp), c("time", "amt", "rate", "ii", "addl", "evid"))
-            expect_false(inherits(tmp$rate, "rxRateDur"))
-            expect_false(inherits(tmp$evid, "rxEvid"))
-        })
+        ## test_that("tibble conversion", {
+        ##     tmp <- tibble::as_tibble(ev)
+        ##     expect_equal(names(tmp), c("time", "amt", "rate", "ii", "addl", "evid"))
+        ##     expect_false(inherits(tmp$rate, "rxRateDur"))
+        ##     expect_false(inherits(tmp$evid, "rxEvid"))
+        ## })
 
-        test_that("tibble conversion #2", {
-            tmp <- dplyr::as.tbl(ev)
-            expect_equal(names(tmp), c("time", "amt", "rate", "ii", "addl", "evid"))
-            expect_false(inherits(tmp$rate, "rxRateDur"))
-            expect_false(inherits(tmp$evid, "rxEvid"))
-        })
+        ## test_that("tibble conversion #2", {
+        ##     tmp <- dplyr::as.tbl(ev)
+        ##     expect_equal(names(tmp), c("time", "amt", "rate", "ii", "addl", "evid"))
+        ##     expect_false(inherits(tmp$rate, "rxRateDur"))
+        ##     expect_false(inherits(tmp$evid, "rxEvid"))
+        ## })
     }
 
     test_that("errors", {
@@ -492,4 +493,13 @@ rxPermissive({
 
     })
 
+    context("Issue #192 zero dose")
+    test_that("dose=0 is OK", {
+        ev1 <- et(amt=0, time=10)
+        ev2 <- eventTable();
+        ev2$add.dosing(dose=0, start.time=10)
+
+        expect_equal(ev1, ev2)
+    })
+
 }, silent=TRUE, cran=TRUE)
